package com.admost.admost_flutter_plugin;

import android.app.Activity;
import android.util.Log;

import androidx.annotation.NonNull;
import java.util.ArrayList;
import admost.sdk.base.AdMost;
import admost.sdk.base.AdMostConfiguration;
import admost.sdk.base.AdMostLog;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.plugin.platform.PlatformViewRegistry;

/**
 * FlutterAdmostPlugin
 */
public class AdmostFlutterPlugin implements FlutterPlugin, ActivityAware, MethodCallHandler {
    /**
     * Plugin registration.
     */
    private Activity activity;
    private BinaryMessenger messenger;
    private PlatformViewRegistry platformViewRegistry;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding binding) {
        this.messenger = binding.getBinaryMessenger();
        this.platformViewRegistry = binding.getPlatformViewRegistry();
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) { }

    private void initPlugin() {
        final MethodChannel channel = new MethodChannel(messenger, "admost_flutter");
        channel.setMethodCallHandler(this);

        final MethodChannel interstitialChannel = new MethodChannel(messenger, "admost_flutter/interstitial");
        interstitialChannel.setMethodCallHandler(new AdmostIntersitital(activity, messenger));

        final MethodChannel rewardChannel = new MethodChannel(messenger, "admost_flutter/rewarded");
        rewardChannel.setMethodCallHandler(new AdmostRewarded(activity, messenger));

        platformViewRegistry.registerViewFactory("admost_flutter/banner", new AdmostBannerFactory(messenger, activity));
    }

    @Override
    public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
        activity = binding.getActivity();
        initPlugin();
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() { }

    @Override
    public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {  }

    @Override
    public void onDetachedFromActivity() { }

    String subjectToGDPR, subjectToCCPA, userConsent;

    @Override
    public void onMethodCall(MethodCall call, final Result result) {
        if (call.method.equals("initialize")) {
            String appId = call.argument("appId");
            AdMostConfiguration.Builder configuration = new AdMostConfiguration.Builder(activity, appId);
            if (call.hasArgument("subjectToGDPR") && call.argument("subjectToGDPR") != null) {
                subjectToGDPR = call.argument("subjectToGDPR");
                configuration.setSubjectToGDPR(subjectToGDPR.equals("1"));
            }
            if (call.hasArgument("subjectToCCPA") && call.argument("subjectToCCPA") != null) {
                subjectToCCPA = call.argument("subjectToCCPA");
                configuration.setSubjectToCCPA(subjectToCCPA.equals("1"));
            }
            if (call.hasArgument("userConsent") && call.argument("userConsent") != null) {
                userConsent = call.argument("userConsent");
                configuration.setUserConsent(userConsent.equals("1"));
            }

            AdMost.getInstance().init(configuration.build());
        } else if (call.method.equals("startTestSuite")) {
            AdMost.getInstance().startTestSuite();
        } else if (call.method.equals("isPrivacyConsentRequired")) {
            AdMost.getInstance().setPrivacyConsentListener(activity, new AdMost.PrivacyConsentListener() {
                @Override
                public void isPrivacyConsentRequired(String s) {
                    result.success(s);
                }
            });
        } else if (call.method.equals("trackIAP")) {
            try {
                String originalJSON = call.argument("originalJSON");
                String signature = call.argument("signature");
                String currencyCode = call.argument("currencyCode");
                Double price = call.argument("price");
                ArrayList<String> tags = call.argument("tags");

                String[] tagsToSend = null;
                if (tags != null) {
                    tagsToSend = tags.toArray(new String[0]);
                }
                trackIAP(originalJSON, signature, currencyCode, price, tagsToSend);

            } catch (Exception ex) {
                ex.printStackTrace();
                Log.w("ADMOST", "argument exception");
            }

        } else if (call.method.equals("setUserId")) {
            String userId = call.argument("userId");
            AdMost.getInstance().setUserId(userId);
        }

    }

    private void trackIAP(String originalJSON, String signature, String isoCurrencyCode, Double price, final String[] tags) {
        double localizedPriceDoubleInMicros = price * 1000000;
        final String toSendSku = "{\"price_amount_micros\":" + localizedPriceDoubleInMicros + ",\"price_currency_code\":\"" + isoCurrencyCode + "\"}";
        if (originalJSON.length() > 0 && signature.length() > 0) {
            AdMost.getInstance().trackIAP(originalJSON, signature, toSendSku, tags, false);
        } else {
            Log.w("ADMOST", "Something wrong with your data");
        }
    }

}
