//
//  AdmostBanner.m
//  admost_flutter_plugin
//
//  Created by Mehmet Karagöz on 9.12.2019.
//

#import "AdmostBanner.h"
#import <AMRSDK/AMRSDK.h>

@interface AdmostBanner () <AMRBannerDelegate> @end

@implementation AdmostBanner {
    FlutterMethodChannel *_channel;
    NSObject<FlutterBinaryMessenger> *_messenger;
    CGRect _frame;
    int64_t _viewId;
    NSDictionary *_args;
    AMRBanner *_banner;
    UIView *_bannerContainer;
}

#pragma mark - NSObject

+ (instancetype)bannerWithFrame:(CGRect)frame viewIdentifier:(int64_t)viewId arguments:(NSDictionary *)args messenger:(NSObject<FlutterBinaryMessenger> *)messenger {
    return [[[self class] alloc] initWithFrame:frame viewIdentifier:viewId arguments:args messenger:messenger];
}

- (instancetype)initWithFrame:(CGRect)frame viewIdentifier:(int64_t)viewId arguments:(NSDictionary *)args messenger:(NSObject<FlutterBinaryMessenger> *)messenger {
    if (!(self = [super init]))
        return nil;
    _frame = frame;
    _viewId = viewId;
    _args = args;
    _messenger = messenger;
    _channel = [FlutterMethodChannel methodChannelWithName:[NSString stringWithFormat:@"admost_flutter/banner_%@", @(viewId)] binaryMessenger:_messenger];
    
    return self;
}

#pragma mark - FlutterPlatformView

- (nonnull UIView *)view {
    return [self bannerAdView];
}

#pragma mark - Private

- (void)dispose {
    if (_banner) {
        [_banner.bannerView removeFromSuperview];
        _banner = nil;
        [_channel setMethodCallHandler:nil];
    }
}

- (UIView *)bannerAdView {
    if (!_banner) {
        _banner = [AMRBanner bannerForZoneId:_args[@"adUnitId"]];
        CGSize size = [self size];

        if([_args[@"isNativeAd"]  isEqual: @"true"]){
            NSString *xibName = _args[@"xibName"];
            _banner.customeNativeXibName = xibName;
            _banner.customNativeSize = size;
        }
        
        _bannerContainer = [[UIView alloc] initWithFrame:CGRectMake(0, 0, size.width, size.height)];
        
        __weak typeof(self) weakSelf = self;
        [_channel setMethodCallHandler:^(FlutterMethodCall * _Nonnull call, FlutterResult  _Nonnull result) {
            if ([call.method isEqualToString:@"setListener"]) {
                [weakSelf setBannerDelegate];
            } else if ([call.method isEqualToString:@"dispose"]) {
                [weakSelf dispose];
            } else {
                result(FlutterMethodNotImplemented);
            }
        }];
        
        if ([_args[@"tag"] isKindOfClass: [NSNull class]] || _args[@"tag"] == nil ) {
            [_banner loadBanner];
        } else {
            [_banner loadBannerWithTag: _args[@"tag"]];
        }
    }
    
    return _bannerContainer;
}

- (CGSize)size {
    if (_args[@"adSize"]) {
        return CGSizeMake([_args[@"adSize"][@"width"] doubleValue], [_args[@"adSize"][@"height"] doubleValue]);
    }
    
    return CGSizeMake(0, 0);
}

- (void)setBannerDelegate {
    _banner.delegate = self;
}

#pragma mark - <AMRBannerDelegate>

- (void)didReceiveBanner:(AMRBanner *)banner {
    [_bannerContainer addSubview:banner.bannerView];
    [_channel invokeMethod:@"loaded" arguments:@{
        @"network": banner.networkName ,
        @"ecpm": banner.ecpm 
    }];
}

- (void)didFailToReceiveBanner:(AMRBanner *)banner error:(AMRError *)error {
    [_channel invokeMethod:@"failedToLoad" arguments:@{
        @"errorCode": [NSNumber numberWithInt:error.errorCode] ,
        @"errorMessage": error.errorDescription
    }];
}

- (void)didClickBanner:(AMRBanner *)banner {
    [_channel invokeMethod:@"clicked" arguments:@{
        @"network": banner.networkName ,
    }];
}


@end
