//
//  AdmostRewardedVideoDelegate.m
//  admost_flutter_plugin
//
//  Created by Mehmet Karagöz on 9.12.2019.
//

#import "AdmostRewardedVideoDelegate.h"

@implementation AdmostRewardedVideoDelegate {
    FlutterMethodChannel *_channel;
}

#pragma mark - NSObject

+ (instancetype)delegateWithChannel:(FlutterMethodChannel *)channel {
    return [[[self class] alloc] initWithChannel:channel];
}

- (instancetype)initWithChannel:(FlutterMethodChannel *)channel {
    if (!(self = [super init]))
        return nil;
    _channel = channel;
    return self;
}

#pragma mark - <AMRRewardedVideoDelegate>

- (void)didReceiveRewardedVideo:(AMRRewardedVideo *)rewardedVideo {
    [_channel invokeMethod:@"loaded" arguments:@{
        @"network": rewardedVideo.networkName ,
        @"ecpm": rewardedVideo.ecpm 
    }];
}

- (void)didFailToReceiveRewardedVideo:(AMRRewardedVideo *)rewardedVideo error:(AMRError *)error {
    [_channel invokeMethod:@"failedToLoad" arguments:@{
        @"errorCode": [NSNumber numberWithInt:error.errorCode] ,
        @"errorMessage": error.errorDescription
    }];
}

- (void)didShowRewardedVideo:(AMRRewardedVideo *)rewardedVideo {
    [_channel invokeMethod:@"opened" arguments:@{
        @"network": rewardedVideo.networkName,
    }];
}

- (void)didFailToShowRewardedVideo:(AMRRewardedVideo *)rewardedVideo error:(AMRError *)error {
    [_channel invokeMethod:@"failedToShow" arguments:@{
        @"errorCode": [NSNumber numberWithInt:error.errorCode] ,
        @"errorMessage": error.errorDescription
    }];
}

- (void)didClickRewardedVideo:(AMRRewardedVideo *)rewardedVideo {
    [_channel invokeMethod:@"clicked" arguments:@{
        @"network": rewardedVideo.networkName,
    }];
}

- (void)didDismissRewardedVideo:(AMRRewardedVideo *)rewardedVideo {
    [_channel invokeMethod:@"dismissed" arguments:nil];
}

- (void)didCompleteRewardedVideo:(AMRRewardedVideo *)rewardedVideo {
    [_channel invokeMethod:@"completed" arguments:@{
        @"network": rewardedVideo.networkName,
    }];
}

@end
