//
//  AdmostSDKPlugin.m
//  admost_flutter_plugin
//
//  Created by Mehmet Karagöz on 9.12.2019.
//

#import "AdmostSDKPlugin.h"
#import "AdmostBannerFactory.h"
#import <AMRSDK/AMRSDK.h>
#import <AppTrackingTransparency/AppTrackingTransparency.h>


@implementation AdmostSDKPlugin

+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
    AdmostSDKPlugin *instance = [[AdmostSDKPlugin alloc] init];
    FlutterMethodChannel *defaultChannel = [FlutterMethodChannel methodChannelWithName:@"admost_flutter"
                                                                       binaryMessenger:registrar.messenger];
    [registrar addMethodCallDelegate:instance channel:defaultChannel];
    
    AdmostBannerFactory *bannerFactory = [AdmostBannerFactory bannerFactoryWithMessenger:registrar.messenger];
    [registrar registerViewFactory:bannerFactory
                            withId:@"admost_flutter/banner"];
}

- (void)handleMethodCall:(FlutterMethodCall *)call result:(FlutterResult)result {
    /*if (call.arguments == nil ||
        ![call.arguments isKindOfClass:[NSDictionary class]]) {
        result(FlutterMethodNotImplemented);
        return;
    }*/
    
    NSDictionary *parameters = (NSDictionary *)call.arguments;
    
    if ([parameters objectForKey:@"subjectToCCPA"] &&
        parameters[@"subjectToCCPA"] != (id)[NSNull null]) {
        
        NSString *stringParam = parameters[@"subjectToCCPA"];
        BOOL subjectToCCPA = [stringParam boolValue];
        NSLog(@"ccpa%@", stringParam);
        [AMRSDK subjectToCCPA:subjectToCCPA];
    }
    
    if ([parameters objectForKey:@"subjectToGDPR"] &&
        parameters[@"subjectToGDPR"] != (id)[NSNull null]) {
        
        NSString *stringParam = parameters[@"subjectToGDPR"];
        BOOL subjectToGDPR = [stringParam boolValue];
        NSLog(@"subjectToGDPR%@", stringParam);

        [AMRSDK subjectToGDPR:subjectToGDPR];
    }
    
    if ([parameters objectForKey:@"userConsent"] &&
        parameters[@"userConsent"] != (id)[NSNull null]) {
        NSString *stringParam = parameters[@"userConsent"];
        BOOL userConsent = [stringParam boolValue];
        NSLog(@"userConsent%@", stringParam);

        [AMRSDK setUserConsent:userConsent];
    }

    if ([call.method isEqualToString:@"initialize"]) {
        if(parameters[@"appId"] != (id)[NSNull null]){
            NSString *appId = parameters[@"appId"];
            [AMRSDK startWithAppId:appId];
        }
    } else if ([call.method isEqualToString:@"startTestSuite"]) {
         if(parameters[@"appId"] != (id)[NSNull null]){
            NSString *appId = parameters[@"appId"];
            [AMRSDK startTesterInfoWithAppId:appId];
        }
    } else if ([call.method isEqualToString:@"trackIAP"]) {
        double amount = [parameters[@"amount"] doubleValue];
        
        NSArray *tagss = [NSArray new];
        if ([parameters objectForKey:@"tags"] &&
            parameters[@"tags"] != (id)[NSNull null] &&
            [parameters[@"tags"] isKindOfClass:[NSArray class]]) {
            tagss = [NSArray arrayWithArray:parameters[@"tags"]];
        }
        
        [AMRSDK trackIAP:parameters[@"identifier"] currencyCode:parameters[@"currencyCode"] amount:amount tags:tagss];
    } else if ([call.method isEqualToString:@"setUserId"]) {
        if(parameters[@"userId"] != (id)[NSNull null]){
            NSString *userId = parameters[@"userId"];
            [AMRSDK setUserId:userId];  
        }
    } else if ([call.method isEqualToString:@"requestTrackingAuthorization"]) {
        if (@available(iOS 14.5, *)) {
            [ATTrackingManager requestTrackingAuthorizationWithCompletionHandler:^(ATTrackingManagerAuthorizationStatus status) {
                result([NSNumber numberWithInteger:status]);
            }];
        } else {
            result(0);
        }
    } else if ([call.method isEqualToString:@"getTrackingAuthorizationStatus"]) {
        if (@available(iOS 14.5, *)) {
            result([NSNumber numberWithInteger:[ATTrackingManager trackingAuthorizationStatus]]);
        } else {
            result(0);
        }
    } else if ([call.method isEqualToString:@"isPrivacyConsentRequired"]) {
        [AMRSDK isPrivacyConsentRequired:^(AMRPrivacyConsentStatus consentStatus) {
            if (consentStatus == AMRPrivacyConsentStatusNone) {
                result(@"None");
            } else if (consentStatus == AMRPrivacyConsentStatusGDPR) {
                result(@"GDPR");
            }
            else if (consentStatus == AMRPrivacyConsentStatusCCPA) {
                result(@"CCPA");
            }
        }];
    } else {
        result(FlutterMethodNotImplemented);
    }
}

@end
